---
name: Feature request
about: Suggest an idea for the Molecule project
labels: enhancement
---

# Issue Type

- Feature request

# Molecule and Ansible details

```
ansible --version && molecule --version
```

Molecule installation method (one of):

- source
- pip

Ansible installation method (one of):

- source
- pip
- OS package

# Desired Behavior

Please give some details of the feature being requested
